@@ -2,8 +2,7 @@ use std::ops::DerefMut;
 use swc_atoms::js_word;
 use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::AsOptExpr;
-use swc_ecma_transforms_base::ext::PatOrExprExt;
+use swc_ecma_transforms_base::ext::{AsOptExpr, PatOrExprExt};
 use swc_ecma_utils::quote_ident;
 use swc_ecma_visit::{noop_fold_type, Fold, FoldWith};
 
